Branch: master

2d7de7ce 2019-08-09 08:57:24 Chris
Replace Qt branding with TQt ones.

Signed-off-by: Chris <xchrisx@...>
M kcontrol/style/kcmstyle.cpp
M konsole/konsole/main.cpp

kcontrol/style/kcmstyle.cpp

diff --git a/kcontrol/style/kcmstyle.cpp b/kcontrol/style/kcmstyle.cpp
index d6a7ae6..a51a63e 100644
--- a/kcontrol/style/kcmstyle.cpp
+++ b/kcontrol/style/kcmstyle.cpp
@@ -1097,7 +1097,7 @@
 
 	// Page3
 	TQWhatsThis::add( page3, i18n("<b>Note:</b> that all widgets in this combobox "
-							"do not apply to Qt-only applications.") );
+							"do not apply to TQt-only applications.") );
 	TQWhatsThis::add( cbHoverButtons, i18n("If this option is selected, toolbar buttons will change "
 							"their color when the mouse cursor is moved over them." ) );
 	TQWhatsThis::add( cbTransparentToolbars, i18n("If you check this box, the toolbars will be "

konsole/konsole/main.cpp

diff --git a/konsole/konsole/main.cpp b/konsole/konsole/main.cpp
index e18d52c..4039362 100644
--- a/konsole/konsole/main.cpp
+++ b/konsole/konsole/main.cpp
@@ -86,7 +86,7 @@
    { "schema <name> | <file>",   I18N_NOOP("Set schema to 'name' or use 'file'"), 0 },
    { "schemas",         0, 0 },
    { "schemata",        I18N_NOOP("List available schemata"), 0 },
-   { "script",          I18N_NOOP("Enable extended DCOP Qt functions"), 0 },
+   { "script",          I18N_NOOP("Enable extended DCOP TQt functions"), 0 },
    { "workdir <dir>",   I18N_NOOP("Change working directory to 'dir'"), 0 },
    { "!e <command>",    I18N_NOOP("Execute 'command' instead of shell"), 0 },
    // WABA: All options after -e are treated as arguments.
@@ -238,15 +238,15 @@
   TEWidget::setAntialias( !has_noxft );
   TEWidget::setStandalone( true );
 
   // The following Qt options have no effect; warn users.
   if( qtargs->isSet("background") )
-      kdWarning() << "The Qt option -bg, --background has no effect." << endl;
+      kdWarning() << "The TQt option -bg, --background has no effect." << endl;
   if( qtargs->isSet("foreground") )
-      kdWarning() << "The Qt option -fg, --foreground has no effect." << endl;
+      kdWarning() << "The TQt option -fg, --foreground has no effect." << endl;
   if( qtargs->isSet("button") )
-      kdWarning() << "The Qt option -btn, --button has no effect." << endl;
+      kdWarning() << "The TQt option -btn, --button has no effect." << endl;
   if( qtargs->isSet("font") )
-      kdWarning() << "The Qt option -fn, --font has no effect." << endl;
+      kdWarning() << "The TQt option -fn, --font has no effect." << endl;
 
   TDEApplication* a = NULL;
 #ifdef COMPOSITE
@@ -238,15 +238,15 @@
   TEWidget::setStandalone( true );
 
-  // The following Qt options have no effect; warn users.
+  // The following TQt options have no effect; warn users.
   if( qtargs->isSet("background") )